@@ -9,7 +9,7 @@ def reports(deployment_id,token):
     }
 
     url = f'{base_url}/plot/report'
-    access_token = 'Bearer '+ {token}
+    access_token = 'Bearer '+ token
     headers = {"Authorization": access_token}
     response = requests.post(url, data=data,headers=headers)
     pdf_data = response.content
@@ -29,7 +29,7 @@ def read_file(file_path):
 
 
 
-def EDAreport(file_path,target,client_id,client_token):
+def EDAreport(file_path,target,client_id,token):
     uploaded_filename, content = read_file(file_path)
     data = {
     'target': target,
@@ -37,6 +37,7 @@ def EDAreport(file_path,target,client_id,client_token):
     }
     url = f"{base_url}/training/eda-report"
     files = {'file': (uploaded_filename, content)}
-    headers = {"Authorization": client_token}
+    access_token = 'Bearer '+ token
+    headers = {"Authorization": access_token}
     response = requests.post(url, data=data, files=files,headers=headers)
     return response.json()
\ No newline at end of file
